summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorBeniamino Galvani <bgalvani@redhat.com>2022-07-15 10:52:11 +0200
committerBeniamino Galvani <bgalvani@redhat.com>2022-07-18 07:48:12 +0200
commit0717589972324bc06b9b5324134a45a543c80aa4 (patch)
tree0cd4ea7172c1e8828972f93ad46344d236bdd711
parent2ae8433520be69b95dccefba416c19d28fb38a85 (diff)
downloadNetworkManager-0717589972324bc06b9b5324134a45a543c80aa4.tar.gz
wwan: enable manual IP configuration
Before 1.36, manual addresses from the profile were assigned to the interface; restore that behavior. The manual IP configuration also contains the DNS priority from the profile; so this change ensures that the merged l3cd has a DNS priority and that dynamically discovered DNS servers are not ignored by the DNS manager. Fixes: 58287cbcc0c8 ('core: rework IP configuration in NetworkManager using layer 3 configuration')
-rw-r--r--src/core/devices/wwan/nm-device-modem.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/core/devices/wwan/nm-device-modem.c b/src/core/devices/wwan/nm-device-modem.c
index 8c00a6d3f9..e0209affcd 100644
--- a/src/core/devices/wwan/nm-device-modem.c
+++ b/src/core/devices/wwan/nm-device-modem.c
@@ -623,11 +623,11 @@ is_available(NMDevice *device, NMDeviceCheckDevAvailableFlags flags)
static gboolean
ready_for_ip_config(NMDevice *device, gboolean is_manual)
{
/* Tell NMDevice to only run device-specific IP
* configuration (devip) and skip other methods
- * (manual, dhcp, etc).
+ * (dhcp, link-local, shared, etc).
*/
- return FALSE;
+ return is_manual;
}
/*****************************************************************************/
@@ -623,11 +623,11 @@ is_available(NMDevice *device, NMDeviceCheckDevAvailableFlags flags)
ready_for_ip_config(NMDevice *device, gboolean is_manual)
{
- /* Tell NMDevice to only run device-specific IP
+ /* Tell NMDevice to only run manual and device-specific IP
* configuration (devip) and skip other methods